@@ -12,7 +12,7 @@ my $obj = MARC::Leader->new;
 # Data object.
 my $data_marc_leader = Data::MARC::Leader->new(
         'bibliographic_level' => 'm',
-        'char_encoding_scheme' => 'a',
+        'char_coding_scheme' => 'a',
         'data_base_addr' => 541,
         'descriptive_cataloging_form' => 'i',
         'encoding_level' => ' ',
